@@ -9,7 +9,8 @@ class BaseResponse(BaseModel):
 
 
 class LoadModelsResponse(BaseResponse):
-    loaded_models_count: int
+    success_count: int
+    fail_count: int
 
 
 class GenerateHintResponse(BaseResponse):
